@@ -47,8 +47,8 @@ class ShowConsoleLog(command.Command):
         )
         return parser
 
+    @utils.log_method(log)
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         compute_client = self.app.client_manager.compute
 
         server = utils.find_resource(
@@ -103,8 +103,8 @@ class ShowConsoleURL(show.ShowOne):
         )
         return parser
 
+    @utils.log_method(log)
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         compute_client = self.app.client_manager.compute
         server = utils.find_resource(
             compute_client.servers,
